{#
# This file is part of Invenio.
# Copyright (C) 2014, 2015, 2016 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#}

{%- extends config.WORKFLOWS_UI_BASE_TEMPLATE %}

{% set title = _("Your Pending Actions") %}

{% block page_body %}
    <div class="container">
        <div class="row">
            <div class="col-md-12">
                <h2>Workflows Dashboard</h2>
                <a href="{{ url_for('invenio_workflows_ui.list_objects')|safe }}"
                   class="btn btn-primary btn-lg" role="button">{{ _('Go to list') }}</a>
            </div>
        </div>
    </div>
{% endblock %}
